@@ -5,8 +5,8 @@
 package bifs
 
 import (
-	"github.com/johnkerl/miller/pkg/lib"
-	"github.com/johnkerl/miller/pkg/mlrval"
+	"github.com/johnkerl/miller/v6/pkg/lib"
+	"github.com/johnkerl/miller/v6/pkg/mlrval"
 )
 
 //   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
