@@ -74,7 +74,7 @@ import (
 	"os"
 	"strconv"
 
-	"github.com/johnkerl/miller/pkg/lib"
+	"github.com/johnkerl/miller/v6/pkg/lib"
 )
 
 // ================================================================
