@@ -8,7 +8,7 @@ import (
 	"errors"
 	"fmt"
 
-	"github.com/johnkerl/miller/pkg/lib"
+	"github.com/johnkerl/miller/v6/pkg/lib"
 )
 
 // TODO: comment for JSON-scanner context.
@@ -197,6 +197,15 @@ func FromInt(input int64) *Mlrval {
 	}
 }
 
+func FromIntShowingOctal(input int64) *Mlrval {
+	return &Mlrval{
+		mvtype:        MT_INT,
+		printrepValid: true,
+		printrep:      fmt.Sprintf("0%o", input),
+		intf:          input,
+	}
+}
+
 // TryFromIntString is used by the mlrval Formatter (fmtnum DSL function,
 // format-values verb, etc).  Each mlrval has printrep and a printrepValid for
 // its original string, then a type-code like MT_INT or MT_FLOAT, and
@@ -309,7 +318,7 @@ func (mv *Mlrval) SetFromPrevalidatedBoolString(input string, boolval bool) *Mlr
 
 // The user-defined function is of type 'interface{}' here to avoid what would
 // otherwise be a package-dependency cycle between this package and
-// github.com/johnkerl/miller/pkg/dsl/cst.
+// github.com/johnkerl/miller/v6/pkg/dsl/cst.
 //
 // Nominally the name argument is the user-specified name if `func f(a, b) {
 // ... }`, or some autogenerated UUID like `fl0052` if `func (a, b) { ... }`.
