@@ -4,8 +4,8 @@ import (
 	"container/list"
 	"os"
 
-	"github.com/johnkerl/miller/pkg/cli"
-	"github.com/johnkerl/miller/pkg/types"
+	"github.com/johnkerl/miller/v6/pkg/cli"
+	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
 // IRecordTransformer is the interface satisfied by all transformers, i.e.,
